@@ -81,7 +81,10 @@ class GraphQLView(BaseGraphQLView):
                 result = "[{}]".format(",".join([response[0] for response in responses]))
                 status_code = (responses and max(responses, key=lambda response: response[1])[1] or 200)
             else:
-                result, status_code = self.get_response(request, data, show_graphiql)
+                result, status_code = self.get_response(
+                    request, data,
+                    allowGraphiQL and self.can_display_graphiql(request, data)
+                )
             return respond_handling_authentication(status_code=status_code, result=json.loads(result), request=request)
 
         except HttpError as e:
@@ -151,6 +154,8 @@ class GraphQLView(BaseGraphQLView):
             return {"message": error.__repr__(), "code": "ATTRIBUTE_ERROR"}
         if isinstance(error, TypeError):
             return {"message": error.__repr__(), "code": "TYPE_ERROR"}
+        if isinstance(error, KeyError):
+            return {"message": error.__repr__(), "code": "KEY_ERROR"}
         return self.format_response_error(error)
 
     def format_error(self, error):
